function [best_nfa best_line_pos best_line_ors all_nfas] = algoVR(points, orientations)
% [best_nfa best_line_pos best_line_ors all_nfas] = algoVR(points, orientations)
%
% - points : a N x 2 matrix; each line contains the coordinates of a point
% - orientations : a vector of length N, containing the orientations of the
%   patches
%
% - best_nfa : the smallest found NFA
% - best_line_pos : the coordinates of the elements of the detected
%   alignment
% - all_nfas : the NFA values of all tested chains

N = length(points);% total number of elements
nn = 6; % number of nearest neighbours in the initial graph
D = dist2(points, points); % matrix of square distances between points
gamma = knn_oriented(D, nn); % adjacence matrix defining the edges of the oriented graph gamma

%% Build the list of maximal chains (with floor(sqrt(N)) elements each)
maximal_chains = {};
for i = 1:N,
    maximal_chains = [maximal_chains, list_chains_starting_at(i, gamma, points, floor(sqrt(N)))];
end

%% Test all subchains (at least 3 elements long) of the maximal chains
best_nfa = inf;
best_chain = [];
all_nfas = [];
for i =1:length(maximal_chains), 
    c_i = maximal_chains{i};
    n_i = length(c_i);
    for l = 3 : n_i,
        sub_chain = c_i(1 : l);
        nfa_chain = nfa(sub_chain, points, orientations);
        all_nfas = [all_nfas, nfa_chain];
        if nfa_chain < best_nfa,
            best_nfa = nfa_chain;
            best_chain = sub_chain;
        end
    end
end

best_line_pos = points(best_chain, :); % coordinates of the elements in the detected alignment
best_line_ors = orientations(best_chain, :);% orientations of the elements in the detected alignment