function chain_out = expand_chain(M, chain, points, n)
% chain_out = expand_chain(M, chain, points, n)
%
%   points : is a N x 2 matrix, each line representing a point's coordinates
%   M : is a NxN adjacence (binary) matrix representing an oriented graph on the points
%   n  : is an integer, the max. number of elements in the current chain to
%   build
%
%   Returns a maximal chain (i. e. with at most n points), noted chain_out,
%   that expands in the most rectilinear way an existing chain in input.

i = chain(end);
v = find(M(i, :)); % indexes of point i's neighbors

if length(chain) >= n || isempty(v),
    chain_out = chain;
else
    x = points(chain(end-1), :);
    y = points(chain(end), :);
    max_cos_phi = -1;
    jmax = v(1);
    for k = 1:length(v),
        j = v(k);
        z = points(j, :);
        scalar_prod = (y-x)*(z-y)';
        cos_phi = scalar_prod/sqrt(((y-x)*(y-x)')*((z-y)*(z-y)'));
        if cos_phi > max_cos_phi,
            max_cos_phi = cos_phi;
            jmax = j;
        end
    end
    if  ~ismember(jmax, chain),
        new_chain = [chain, jmax];
        chain_out = expand_chain(M, new_chain, points, n);
    else
        chain_out = chain;
    end
end