clear;
close all;
%% Directory containing the stimuli files
stimuli_directory = fullfile('..', 'stimuli_files');

%% Choice of the stimulus (choose the sequence and 4 parameters)
seq = 'N100'; % name of the sequence of stimuli: 'N100', 'N200_1', 'N200_2', 'N200_3', 'N200_4', 'N600' 
n = 9;% number of aligned elements, between 4 and 9
j = 1;% jitter level, j = 1, 2, 3, 4, 5, 9 corresponding respectively to 
      % alpha = 9°, 15°, 22.5°, 30°, 45°, 90°
s = 1; % stimulus number, integer between 1 and 4 if j < 9, 
       % s = 1 if j = 9
correct_stim_number;

%% Read the corresponding file and display the image

stim_name = [seq(1:4), 'k', int2str(n), 'jitter', int2str(j), 'stim', int2str(s)];
points = dlmread(fullfile(stimuli_directory, seq, [stim_name, 'all.txt']));
orientations = dlmread(fullfile(stimuli_directory, seq, [stim_name, 'all_ors.txt']));

% Parameters for the image
img_side = 500; % size of the image's side, in pixels
freq = 0.12; % spatial frequence for the gabor patches, in cycles per pixel
patch_side = 15; % size of each patch's side, in pixels
sigma = 1/(4*freq*patch_side);
% Build image
IMG_stimulus = gab_array(img_side, img_side, patch_side, patch_side, points, orientations, sigma, freq*patch_side);
imshow(IMG_stimulus);

%% Run the algorithm
[best_nfa best_line_pos best_line_ors all_nfas] = algoVR(points, orientations);

%% Build and display output image
%IMG_detection = gert_img(best_line_pos, -best_line_ors, img_side, freq);
IMG_detection = gab_array(img_side, img_side, patch_side, patch_side, best_line_pos, best_line_ors, sigma, freq*patch_side);
figure;
imshow(IMG_detection);
fprintf('The detected chain has NFA = %g.\n', best_nfa);